# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: helloworld.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='helloworld.proto',
    package='',
    syntax='proto3',
    serialized_options=None,
    serialized_pb=b'\n\x10helloworld.proto\"!\n\x11HelloWorldRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"%\n\x12HelloWorldResponse\x12\x0f\n\x07message\x18\x01 \x01(\t2\x84\x01\n\x11HelloWorldService\x12\x33\n\x08SayHello\x12\x12.HelloWorldRequest\x1a\x13.HelloWorldResponse\x12:\n\x0bStreamHello\x12\x12.HelloWorldRequest\x1a\x13.HelloWorldResponse(\x01\x30\x01\x62\x06proto3'
)

_HELLOWORLDREQUEST = _descriptor.Descriptor(
    name='HelloWorldRequest',
    full_name='HelloWorldRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='name', full_name='HelloWorldRequest.name', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=20,
    serialized_end=53,
)

_HELLOWORLDRESPONSE = _descriptor.Descriptor(
    name='HelloWorldResponse',
    full_name='HelloWorldResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='message', full_name='HelloWorldResponse.message', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=55,
    serialized_end=92,
)

DESCRIPTOR.message_types_by_name['HelloWorldRequest'] = _HELLOWORLDREQUEST
DESCRIPTOR.message_types_by_name['HelloWorldResponse'] = _HELLOWORLDRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

HelloWorldRequest = _reflection.GeneratedProtocolMessageType('HelloWorldRequest', (_message.Message,), {
    'DESCRIPTOR': _HELLOWORLDREQUEST,
    '__module__': 'helloworld_pb2'
    # @@protoc_insertion_point(class_scope:HelloWorldRequest)
})
_sym_db.RegisterMessage(HelloWorldRequest)

HelloWorldResponse = _reflection.GeneratedProtocolMessageType('HelloWorldResponse', (_message.Message,), {
    'DESCRIPTOR': _HELLOWORLDRESPONSE,
    '__module__': 'helloworld_pb2'
    # @@protoc_insertion_point(class_scope:HelloWorldResponse)
})
_sym_db.RegisterMessage(HelloWorldResponse)

_HELLOWORLDSERVICE = _descriptor.ServiceDescriptor(
    name='HelloWorldService',
    full_name='HelloWorldService',
    file=DESCRIPTOR,
    index=0,
    serialized_options=None,
    serialized_start=95,
    serialized_end=227,
    methods=[
        _descriptor.MethodDescriptor(
            name='SayHello',
            full_name='HelloWorldService.SayHello',
            index=0,
            containing_service=None,
            input_type=_HELLOWORLDREQUEST,
            output_type=_HELLOWORLDRESPONSE,
            serialized_options=None,
        ),
        _descriptor.MethodDescriptor(
            name='StreamHello',
            full_name='HelloWorldService.StreamHello',
            index=1,
            containing_service=None,
            input_type=_HELLOWORLDREQUEST,
            output_type=_HELLOWORLDRESPONSE,
            serialized_options=None,
        ),
    ])
_sym_db.RegisterServiceDescriptor(_HELLOWORLDSERVICE)

DESCRIPTOR.services_by_name['HelloWorldService'] = _HELLOWORLDSERVICE

# @@protoc_insertion_point(module_scope)
